@@ -6,56 +6,41 @@ package WWW::Search::Scraper::BAJobs;
 use strict;
 use vars qw($VERSION @ISA);
 @ISA = qw(WWW::Search::Scraper);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 
 use Carp ();
-use WWW::Search::Scraper(qw(1.44 generic_option addURL trimTags));
+use WWW::Search::Scraper(qw(1.48 generic_option addURL trimTags));
 use WWW::Search::Scraper::FieldTranslation;
 
 use LWP::UserAgent;
 use HTML::Form;
 use HTTP::Cookies;
 
-sub native_setup_search
-{
-    my($self, $native_query, $native_options_ref) = @_;
-    $self->{'_options'}{'scraperQuery'} =
-    [ 'FORM'       # 
-      # This is the basic URL on which to get the form to build the query.
-     ,['http://www.bajobs.com/jobseeker/search.jsp', 0, undef]
-      # This names the native input field to recieve the query string.
-     ,{  'nativeDefaults' =>
-                        {
-                             'displayResultsPerPage' => '100'
-                            ,'postingAge' => 30
-                        }
-        ,'fieldTranslations' =>
-                { '*' => 
-                        {    'skills'    => 'searchKeywords'
-                            ,'payrate'   => undef
-                            ,'locations' => new WWW::Search::Scraper::FieldTranslation('BAJobs', 'Job', 'locations')
-                            ,'native_query' => 'searchKeywords'
-                            ,'*'         => '*'
-                        }
-                }
-      }
+my $scraperQuery = 
+   { 
+      'type' => 'FORM'       # Type of query generation is 'FORM'
+      # This is the basic URL on which to build the query.
+     ,'url' => 'http://www.bajobs.com/jobseeker/search.jsp'
+      # This is the Scraper attributes => native input fields mapping
+     ,'nativeQuery' => 'searchKeywords'
+     ,'nativeDefaults' =>
+                            {
+                                 'displayResultsPerPage' => '100'
+                                ,'postingAge' => 30
+                            }
+     ,'fieldTranslations' =>
+                      { '*' => 
+                              {    'skills'    => 'searchKeywords'
+                                  ,'payrate'   => undef
+                                  ,'locations' => new WWW::Search::Scraper::FieldTranslation('BAJobs', 'Job', 'locations')
+                                  ,'*'         => '*'
+                              }
+                      }
       # Some more options for the Scraper operation.
-     ,{'cookies' => 1
-      }
-    ];
-    
-#    $native_query = WWW::Search::unescape_query($native_query); # Thanks, but no thanks, Search.pm!
-#    $self->user_agent('user');
-#    $self->{_next_to_retrieve} = 0;
-#    if (!defined($self->{_options})) {
-#	$self->{_options} = {
-#	    'scraperForm_url' => ['http://www.bajobs.com/jobseeker/search.jsp', 0, 'searchKeywords', undef]
-#        };
-#    };
-#    
-#    $self->cookie_jar(HTTP::Cookies->new());
-#    
-    $self->{'_options'}{'scrapeFrame'} = 
+     ,'cookies' => 0
+   };
+
+my $scraperFrame =
         [ 'HTML', 
            [ 
                [ 'COUNT', 'Job Postings.*?[- 0-9]+.*?of.*?<b>([,0-9]+)</b></font> total']
@@ -88,10 +73,11 @@ sub native_setup_search
            ]
         ];
 
-    # WWW::Search::Scraper understands all that and will setup the search.
-    return $self->SUPER::native_setup_search(@_);
+# Access methods for the structural declarations of this Scraper engine.
+sub scraperQuery { $scraperQuery }
+sub scraperFrame { $_[0]->SUPER::scraperFrame($scraperFrame); }
+sub scraperDetail{ undef }
 
-} # native_setup_search
 
 1;
 
