@@ -2,7 +2,7 @@
 # `make test'. After `make install' it should work as `perl test.pl'
 
 use ExtUtils::testlib;
-$VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 ######################### We start with some black magic to print on failure.
 
@@ -26,7 +26,6 @@ while (<TMP>) {
         next if $1 eq 'apartments';  # went flippo - I'll fix this later.
         next if $1 eq 'BAJobs';     # BAJobs is sick this month - I'll fix later.
 #        next if $1 eq 'techies';     # This one doesn't work, anyway.
-#        next if $1 eq 'FlipDog';     # went flippo - I'll fix this later.
         next if $1 eq 'guru';        # This one doesn't work today, gdw.2001.08.22
         next if $1 eq 'HotJobs';     # HotJobs changed a lot - I'll fix this later.
         next if $1 eq 'JustTechJobs'; # went flippo - I'll fix this later; also, not ready for v2.01 ({'whichTech'}).
@@ -46,7 +45,7 @@ use FileHandle;
     select ($traceFile); $| = 1; select STDOUT;
 
 use strict;
-use WWW::Search::Scraper(qw(1.48));
+use WWW::Search::Scraper(qw(2.13));
 use WWW::Search::Scraper::Request;
     my $loaded = 1;
     $iTest++;
@@ -54,19 +53,19 @@ use WWW::Search::Scraper::Request;
 
 ######################### End of black magic.
 
+
+#######################################################################################
+#
 # Insert your test code below (better if it prints "ok 13"
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
-
-use WWW::Search::Test;
+#
+#######################################################################################
 
 for my $sEngine ( @modules ) {
-    my $debug = 0;
     
-next unless $sEngine eq 'techies';
-
     $iTest++;
-    $traceFile->print("Test #$iTest: $sEngine\n");
+    TRACE("Test #$iTest: $sEngine\n");
     my $oSearch = new WWW::Search::Scraper($sEngine);
     print STDOUT ref($oSearch) ? '' : 'not ';
     print STDOUT "ok $iTest\n";
@@ -74,37 +73,118 @@ next unless $sEngine eq 'techies';
 
 #######################################################################################
 #
-# This test returns no results (but we should not get an HTTP error):
+#       BOGUS QUERY 
+#
+#   This test returns no results (but we should not get an HTTP error):
+#
+#######################################################################################
     $iTest++;
-# Brainpower.com and Dice.com return all jobs if you use Test::bogus_query.
     my $iResults = 0;
+    # Brainpower.com and Dice.com return all jobs if you use Test::bogus_query.
     unless ( $sEngine =~ m/Brainpower|Dice|Monster/ ) {
-        my $bogusRequest = $WWW::Search::Test::bogus_query;
-        my $request = new WWW::Search::Scraper::Request($bogusRequest);
+        my ($sQuery, $options, $onePageCount, $multiPageCount, $bogusPageCount) = $oSearch->setupStandardAndExceptionalOptions($sEngine);
+        $sQuery = "Bogus" . $$ . "NoSuchWord" . time;
+        my $request = new WWW::Search::Scraper::Request($sQuery);
         $oSearch->request($request);
     
         my @aoResults = $oSearch->results();
         $iResults = scalar(@aoResults);
-        print STDOUT ( 0 < $iResults ) ? 'not ' : '';
+        print STDOUT ( $bogusPageCount < $iResults ) ? 'not ' : '';
         print STDERR " --- got $iResults 'bogus' results, expected 0\n" if $iResults > 0;
     }
     print STDOUT "ok $iTest\n";
 
 #######################################################################################
 #
-# This query returns 1 page of results:
+#       ONE-PAGE QUERY
+#
+#   This query returns 1 page of results
+#
+#######################################################################################
+
     $iTest++;
 
 # Set up standard, and exceptional, options.
-my %specialOptions = (
-                         'apartments' => { 'state' => 'NY', 'search_debug' => $debug }
-                        ,'JustTechJobs' => { 'whichTech' => 'Perl' }                                         
-#                        ,'Dice' => {'method'=>'bool', 'acode'=>'650', 'daysback'=>'30', 'search_debug' => $debug}
-                     );
-$oSearch->techiesLocation('bayarea') if $sEngine eq 'techies'; # www.techies.com is special.
-$oSearch->sherlockPlugin('http://sherlock.mozdev.org/yahoo.src') if $sEngine eq 'Sherlock'; # Sherlock is extra special.
+    my ($sQuery, $options, $onePageCount, $multiPageCount, $bogusPageCount) = $oSearch->setupStandardAndExceptionalOptions($sEngine);
 
-my %specialQuery = (
+    # Skip this test if no results are expected anyway.
+    if ( $onePageCount ) {
+        my $request = new WWW::Search::Scraper::Request($sQuery, $options);
+
+        $oSearch->native_query($sQuery); # This let's us test pre-v2.00 modules from here, too.
+        $oSearch->request($request);
+
+        my $maximum_to_retrieve = $onePageCount;
+        $oSearch->maximum_to_retrieve($maximum_to_retrieve); # 1 page
+        my $iResults = 0;
+        eval { 
+            my @aoResults = $oSearch->results();
+            $iResults = scalar(@aoResults);
+        };
+
+        TRACE(" + got $iResults results for $sQuery\n");
+        if ( $maximum_to_retrieve < $iResults )
+          {
+          print STDERR " --- got $iResults results for $sEngine ($sQuery), but expected $maximum_to_retrieve\n";
+          print STDOUT 'not ';
+          }
+    }
+    print STDOUT "ok $iTest\n";
+
+
+#######################################################################################
+#
+#       MULTI-PAGE QUERY
+#
+#   This query returns MANY pages of results
+#
+#######################################################################################
+    $iTest++;
+    my ($sQuery, $options, $onePageCount, $multiPageCount, $bogusPageCount) = $oSearch->setupStandardAndExceptionalOptions($sEngine);
+    # Don't bother with this test if $multiPageCount <= $onePageCount - we've already done it.
+    if ( $multiPageCount > $onePageCount ) {
+        my $maximum_to_retrieve = $multiPageCount; # 2 or 3 pages
+        $oSearch->maximum_to_retrieve($maximum_to_retrieve); # 2 or 3 pages
+        my $request = new WWW::Search::Scraper::Request($sQuery);
+        $oSearch->native_query($sQuery); # This let's us test pre-v2.00 modules from here, too.
+        $oSearch->request($request);
+        $iResults = 0;
+        eval { 
+            while ( $iResults < $maximum_to_retrieve ) {
+                last unless $oSearch->next_response();
+                $iResults += 1;
+            }
+        };
+        TRACE(" ++ got $iResults results for $sQuery\n");
+        if (($iResults < $maximum_to_retrieve ))
+          {
+            # We make an exception for these jobsites, since
+            #  they often turn up few Perl jobs, anyway.
+             unless ( $sEngine =~ m/Brainpower|computerjobs|guru|HotJobs|NorthernLight|Sherlock/ ) {
+                print STDERR " --- got $iResults results for multi-page $sEngine ($sQuery), but expected $maximum_to_retrieve..\n";
+                print STDOUT 'not ';
+            }
+          }
+    }
+    print STDOUT "ok $iTest\n";
+    
+}
+
+
+sub TRACE {
+    $traceFile->print($_[0]);
+    print $_[0] if WWW::Search::Scraper::isGlennWood();
+}
+
+{ package WWW::Search::Scraper;
+# Set up standard, and exceptional, options.
+sub setupStandardAndExceptionalOptions {
+    my ($oSearch, $sEngine) = @_;
+
+    $oSearch->techiesLocation('bayarea') if $sEngine eq 'techies'; # www.techies.com is special.
+    $oSearch->sherlockPlugin('http://sherlock.mozdev.org/yahoo.src') if $sEngine eq 'Sherlock'; # Sherlock is extra special.
+
+    my %specialQuery = (
                          'apartments' => 'New York'
                         ,'eBay'     => 'turntable'
                         ,'Dice'     => 'Perl NOT Java'
@@ -115,70 +195,30 @@ my %specialQuery = (
                         ,'BAJobs'   => 'Service'
                         ,'Monster'  => 'Administrative Assistant'
                         ,'Sherlock' => 'Greeting Cards'
-                   ); 
+                       ); 
     my $sQuery = 'Perl';
     $sQuery = $specialQuery{$sEngine} if defined $specialQuery{$sEngine};
+
+    my %specialOptions = (
+                             'apartments' => { 'state' => 'NY' }
+                            ,'JustTechJobs' => { 'whichTech' => 'Perl' }                                         
+                         );
     my $options = $specialOptions{$sEngine};
     $options = {} unless $options;
-    my $request = new WWW::Search::Scraper::Request($sQuery, $options);
-    $request->Scraper_debug($$options{'search_debug'}?$$options{'search_debug'}:$debug);
-    
-    $oSearch->native_query($sQuery); # This let's us test pre-v2.00 modules from here, too.
-    $oSearch->request($request);
-    
-    #    $request->locations([ 'CA-San Jose'
-    #                         ,'CA-Mountain View'
-    #                         ,'CA-Sunnyvale'
-    #                         ,'CA-Cupertino'
-    ##                         ,'CA-Costa Mesa'
-    #                         ]);
-    
-    my $maximum_to_retrieve = 9;
-    $oSearch->maximum_to_retrieve($maximum_to_retrieve); # 1 page
-    my $iResults = 0;
-    eval { 
-        my @aoResults = $oSearch->results();
-        $iResults = scalar(@aoResults);
-    };
 
-    $traceFile->print(" + got $iResults results for $sQuery\n");
-    if (($iResults < 2) || ( $maximum_to_retrieve < $iResults))
-      {
-      print STDERR " --- got $iResults results for $sEngine ($sQuery), but expected 2..$maximum_to_retrieve\n";
-      print STDOUT 'not ';
-      }
-    print STDOUT "ok $iTest\n";
+    my %defaultPageCounts = (
+                                 'CraigsList' => (9,20,0)
+                                ,'FlipDog' => (5,5,0)
+                                ,'Monster' => (5,5,0)
+                                ,'techies' => (9,9,0)
+                            );
+    my $onePageCount = 9;
+    my $multiPageCount = 41;
+    my $bogusPageCount = 0;
+    ($onePageCount,$multiPageCount,$bogusPageCount) = $defaultPageCounts{$sEngine} if defined $defaultPageCounts{$sEngine};
 
-
-#######################################################################################
-#
-# This query returns MANY pages of results:
-    $iTest++;
-    $maximum_to_retrieve = 41; # 2 or 3 pages
-    $oSearch->maximum_to_retrieve($maximum_to_retrieve); # 2 or 3 pages
-    my $request = new WWW::Search::Scraper::Request($sQuery);
-    $request->Scraper_debug($$options{'search_debug'}?$$options{'search_debug'}:$debug);
-    $oSearch->native_query($sQuery); # This let's us test pre-v2.00 modules from here, too.
-    $oSearch->request($request);
-    $iResults = 0;
-    eval { 
-        while ( $iResults < $maximum_to_retrieve ) {
-            last unless $oSearch->next_response();
-            $iResults += 1;
-        }
-    };
-    $traceFile->print(" ++ got $iResults results for $sQuery\n");
-    if (($iResults < $maximum_to_retrieve ))
-      {
-        # We make an exception for these jobsites, since
-        #  they often turn up few Perl jobs, anyway.
-         unless ( $sEngine =~ m/Brainpower|computerjobs|CraigsList|FlipDog|guru|HotJobs|Monster|NorthernLight|Sherlock/ ) {
-            print STDERR " --- got $iResults results for multi-page $sEngine ($sQuery), but expected $maximum_to_retrieve..\n";
-            print STDOUT 'not ';
-        }
-      }
-    print STDOUT "ok $iTest\n";
-    
+    return ($sQuery,$options,$onePageCount,$multiPageCount,$bogusPageCount);
+}
 }
 
 __END__
